# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.integrations_api import IntegrationsApi  # noqa: E501


class TestIntegrationsApi(unittest.IsolatedAsyncioTestCase):
    """IntegrationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = IntegrationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_v1_integrations_post(self) -> None:
        """Test case for create_v1_integrations_post

        Connect a provider integration  # noqa: E501
        """
        pass

    async def test_delete_integration_v1_integrations_integration_id_delete(self) -> None:
        """Test case for delete_integration_v1_integrations_integration_id_delete

        Disconnect (delete) an integration  # noqa: E501
        """
        pass

    async def test_get_integration_v1_integrations_integration_id_get(self) -> None:
        """Test case for get_integration_v1_integrations_integration_id_get

        Get one integration  # noqa: E501
        """
        pass

    async def test_list_integrations_v1_integrations_get(self) -> None:
        """Test case for list_integrations_v1_integrations_get

        List the portal's provider integrations  # noqa: E501
        """
        pass

    async def test_setup_webhooks_v1_integrations_integration_id_webhooks_setup_post(self) -> None:
        """Test case for setup_webhooks_v1_integrations_integration_id_webhooks_setup_post

        (Re-)register the provider-side webhook  # noqa: E501
        """
        pass

    async def test_sync_products_v1_integrations_integration_id_products_sync_post(self) -> None:
        """Test case for sync_products_v1_integrations_integration_id_products_sync_post

        Sync products from one integration's provider  # noqa: E501
        """
        pass

    async def test_test_credentials_v1_integrations_test_post(self) -> None:
        """Test case for test_credentials_v1_integrations_test_post

        Test provider credentials (before saving)  # noqa: E501
        """
        pass

    async def test_test_integration_v1_integrations_integration_id_test_post(self) -> None:
        """Test case for test_integration_v1_integrations_integration_id_test_post

        Test an integration's saved connection  # noqa: E501
        """
        pass

    async def test_update_integration_v1_integrations_integration_id_patch(self) -> None:
        """Test case for update_integration_v1_integrations_integration_id_patch

        Update an integration (rotate credentials / enable-disable)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
