# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.IsolatedAsyncioTestCase):
    """ProductsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ProductsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_products_v1_products_count_get(self) -> None:
        """Test case for count_products_v1_products_count_get

        Count the portal's products  # noqa: E501
        """
        pass

    async def test_create_product_v1_products_post(self) -> None:
        """Test case for create_product_v1_products_post

        Register a product  # noqa: E501
        """
        pass

    async def test_delete_product_v1_products_product_id_delete(self) -> None:
        """Test case for delete_product_v1_products_product_id_delete

        Delete a product  # noqa: E501
        """
        pass

    async def test_import_products_v1_products_import_post(self) -> None:
        """Test case for import_products_v1_products_import_post

        Bulk-add products by hand (upsert a list)  # noqa: E501
        """
        pass

    async def test_list_products_v1_products_get(self) -> None:
        """Test case for list_products_v1_products_get

        List the portal's products (paginated)  # noqa: E501
        """
        pass

    async def test_sync_all_v1_products_sync_post(self) -> None:
        """Test case for sync_all_v1_products_sync_post

        Sync products from ALL of the portal's integrations  # noqa: E501
        """
        pass

    async def test_update_product_v1_products_product_id_patch(self) -> None:
        """Test case for update_product_v1_products_product_id_patch

        Edit a product (title / external id / archive-restore)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
